@@ -7,7 +7,7 @@ use warnings;
 use XML::DOM;
 use Carp;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 our $ACCESS_KEY = undef;
 
 =head1 NAME
@@ -33,6 +33,11 @@ WWW::Scraper::ISBN::ISBNdb_Driver - isbndb.com driver for WWW::Scraper::ISBN
     print "Year: ", $book->{year}, "\n";
   }
 
+=head1 DESCRIPTION
+
+This is a WWW::Scraper::ISBN driver that pulls data from
+L<http://www.isbndb.com>. Consult L<WWW::Scraper::ISBN> for usage.
+
 =cut
 
 sub search {
@@ -101,6 +106,10 @@ sub _url {
   return sprintf 'http://isbndb.com/api/%s.xml?access_key=%s&index1=%s&results=details&value1=%s', $search_type, $ACCESS_KEY, $search_field, $search_param;
 }
 
+=head1 SEE ALSO
+
+L<WWW::Scraper::ISBN>
+
 =head1 AUTHOR
 
 David J. Iberri, C<< <diberri at cpan.org> >>
